@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import
-
 from .schema import TableSchemaOpts, ModelSchemaOpts, TableSchema, ModelSchema
 
 from .convert import (
@@ -12,9 +9,7 @@ from .convert import (
 )
 from .exceptions import ModelConversionError
 
-__version__ = "0.17.0"
-__license__ = "MIT"
-
+__version__ = "0.21.0"
 __all__ = [
     "TableSchema",
     "ModelSchema",
