@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import inspect
 import functools
 
@@ -34,32 +33,35 @@ def _postgres_array_factory(converter, data_type):
     )
 
 
-class ModelConverter(object):
+class ModelConverter:
     """Class that converts a SQLAlchemy model into a dictionary of corresponding
     marshmallow `Fields <marshmallow.fields.Field>`.
     """
 
     SQLA_TYPE_MAPPING = {
         sa.Enum: fields.Field,
+        sa.JSON: fields.Raw,
         postgresql.BIT: fields.Integer,
+        postgresql.OID: fields.Integer,
         postgresql.UUID: fields.UUID,
         postgresql.MACADDR: fields.String,
         postgresql.INET: fields.String,
+        postgresql.CIDR: fields.String,
         postgresql.JSON: fields.Raw,
         postgresql.JSONB: fields.Raw,
         postgresql.HSTORE: fields.Raw,
         postgresql.ARRAY: _postgres_array_factory,
+        postgresql.MONEY: fields.Decimal,
+        postgresql.DATE: fields.Date,
+        postgresql.TIME: fields.Time,
         mysql.BIT: fields.Integer,
         mysql.YEAR: fields.Integer,
         mysql.SET: fields.List,
         mysql.ENUM: fields.Field,
+        mysql.INTEGER: fields.Integer,
+        mysql.DATETIME: fields.DateTime,
         mssql.BIT: fields.Integer,
     }
-    if hasattr(sa, "JSON"):
-        SQLA_TYPE_MAPPING[sa.JSON] = fields.Raw
-    if hasattr(postgresql, "MONEY"):
-        SQLA_TYPE_MAPPING[postgresql.MONEY] = fields.Decimal
-
     DIRECTION_MAPPING = {"MANYTOONE": False, "MANYTOMANY": True, "ONETOMANY": True}
 
     def __init__(self, schema_cls=None):
@@ -75,6 +77,7 @@ class ModelConverter(object):
     def fields_for_model(
         self,
         model,
+        *,
         include_fk=False,
         fields=None,
         exclude=None,
@@ -105,6 +108,7 @@ class ModelConverter(object):
     def fields_for_table(
         self,
         table,
+        *,
         include_fk=False,
         fields=None,
         exclude=None,
@@ -125,7 +129,7 @@ class ModelConverter(object):
                 result[column.key] = field
         return result
 
-    def property2field(self, prop, instance=True, field_class=None, **kwargs):
+    def property2field(self, prop, *, instance=True, field_class=None, **kwargs):
         field_class = field_class or self._get_field_class_for_property(prop)
         if not instance:
             return field_class
@@ -140,7 +144,7 @@ class ModelConverter(object):
             ret = RelatedList(ret, **kwargs)
         return ret
 
-    def column2field(self, column, instance=True, **kwargs):
+    def column2field(self, column, *, instance=True, **kwargs):
         field_class = self._get_field_class_for_column(column)
         if not instance:
             return field_class
